breakers
0.1.2
Module sampler
Structs
In crate breakers
?
Module
breakers
::
sampler
source
·
[
−
]
Structs

Sample
Sample contains the name and data of a single sample
SamplePlayer
SamplePlayer contains a sample reference and the information which is required to play it
SampleSet